<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>RemoveLayer</name>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="vanished">Odst&amp;ranit vrstvu</translation>
    </message>
    <message>
        <location filename="../RemoveLayerInit.js" line="+2"/>
        <source>&amp;Delete Layer</source>
        <translation>&amp;Odstranit vrstvu</translation>
    </message>
</context>
</TS>
